@@ -225,7 +225,9 @@ multivariate_difference <- function(df,
                                  treatment.var, species.var, time.var, replicate.var)
 
   # order treatment.var if unordered factor
-  to_ordered = is.factor(centers[[treatment.var]]) & !is.ordered(centers[[treatment.var]])
+  to_ordered <- is.factor(centers[[treatment.var]]) &
+    !is.ordered(centers[[treatment.var]]) &
+    is.null(reference.treatment)
   if (to_ordered) {
     class(centers[[treatment.var]]) <- c('ordered', class(centers[[treatment.var]]))
   }
@@ -266,7 +268,7 @@ multivariate_difference <- function(df,
     output$trt_greater_disp[idx] <- NA
     warning('NA(s) produced during dispersion difference calculation.')
   }
-  idx <- !is.na(output$dispersion_diff) & output$dispersion_diff < 0
+  idx <- !is.na(output$dispersion_diff) & output$dispersion_diff > 0
   output$trt_greater_disp[idx] <- output[[treatment.var2]][idx]
   output$abs_dispersion_diff <- abs(output$dispersion_diff)
   output$composition_diff <- mapply(
@@ -324,10 +326,10 @@ pca_centers <- function(df, cluster.var, species.var, split.var, replicate.var)
     d <- as.matrix(vegdist(a, 'bray'))
 
     # perform PCoA aka Torgerson-Gower Scaling, while
-    # violtating the assumption that d results from a metric
+    # violating the assumption that d results from a metric
     b <- -1/2 * dblctr(d^2)
     eig <- eigen(b, symmetric = TRUE)
-    prc <- eig$vectors %*% diag(sqrt(as.complex(eig$values)))
+    prc <- eig$vectors %*% diag(sqrt(as.complex(eig$values)), nrow=nrow(b))
 
     # centroids and dispersion (Marti Anderson, doi:10.1111/j.1541-0420.2005.00440.x)
     by <- c(split.var, cluster.var)
